#[repr(u8)]pub enum Wupmc {
LowPwrOnly = 0,
AnyPwr = 1,
}Variants
LowPwrOnly = 0
Active only during a low-leakage mode. You can modify the corresponding fields within Pin Enable (PEn) or Pin DMA/Trigger Configuration (PDCn).
AnyPwr = 1
Active during all power modes. Do not modify the corresponding fields within Pin Enable (PEn) or Pin DMA/Trigger Configuration (PDCn).
Implementations